@@ -42,10 +42,10 @@ def enabled_signup_methods():
         yield from methods
 
 
-def signup_method_from_slug(slug, shift=None):
+def signup_method_from_slug(slug, shift=None, event=None):
     for method in installed_signup_methods():
         if method.slug == slug:
-            return method(shift)
+            return method(shift, event=event)
     raise ValueError(_("Signup Method '{slug}' was not found.").format(slug=slug))
 
 
@@ -79,18 +79,7 @@ class AbstractParticipant:
 
     @functools.lru_cache
     def collect_all_qualifications(self) -> set:
-        """We collect using breadth first search with one query for every layer of inclusion."""
-        all_qualifications = set(self.qualifications)
-        current = self.qualifications
-        while current:
-            new = (
-                Qualification.objects.filter(included_by__in=current)
-                .exclude(id__in=(q.id for q in all_qualifications))
-                .distinct()
-            )
-            all_qualifications |= set(new)
-            current = new
-        return all_qualifications
+        return Qualification.collect_all_included_qualifications(self.qualifications)
 
     def has_qualifications(self, qualifications):
         return set(qualifications) <= self.collect_all_qualifications()
@@ -333,8 +322,9 @@ class BaseSignupMethod:
 
     uses_requested_state = True
 
-    def __init__(self, shift):
+    def __init__(self, shift, event=None):
         self.shift = shift
+        self.event = getattr(shift, "event", event)
         self.configuration = Namespace(
             **{name: config["default"] for name, config in self.get_configuration_fields().items()}
         )
@@ -423,7 +413,7 @@ class BaseSignupMethod:
         Configure the given participation object for signup according to the method's configuration.
         You need at least to set the participations state. `kwargs` may contain further instructions from e.g. a form.
         """
-        return NotImplemented
+        raise NotImplementedError
 
     def get_configuration_fields(self):
         return OrderedDict(
