@@ -40,8 +40,10 @@ class ShiftCreateView(CustomPermissionRequiredMixin, TemplateView):
         try:
             from ephios.core.signup import signup_method_from_slug
 
-            signup_method = signup_method_from_slug(self.request.POST["signup_method_slug"])
-        except KeyError as e:
+            signup_method = signup_method_from_slug(
+                self.request.POST["signup_method_slug"], event=self.event
+            )
+        except KeyError:
             if not list(signup.enabled_signup_methods()):
                 form.add_error(
                     "signup_method_slug",
@@ -85,11 +87,15 @@ class ShiftCreateView(CustomPermissionRequiredMixin, TemplateView):
             return redirect(self.event.get_absolute_url())
 
 
-class ShiftConfigurationFormView(View):
+class ShiftConfigurationFormView(CustomPermissionRequiredMixin, SingleObjectMixin, View):
+    queryset = Event.all_objects
+    permission_required = "core.change_event"
+    pk_url_kwarg = "event_id"
+
     def get(self, request, *args, **kwargs):
         from ephios.core.signup import signup_method_from_slug
 
-        signup_method = signup_method_from_slug(self.kwargs.get("slug"))
+        signup_method = signup_method_from_slug(self.kwargs.get("slug"), event=self.get_object())
         return HttpResponse(signup_method.render_configuration_form())
 
 
@@ -129,7 +135,9 @@ class ShiftUpdateView(CustomPermissionRequiredMixin, SingleObjectMixin, Template
         try:
             from ephios.core.signup import signup_method_from_slug
 
-            signup_method = signup_method_from_slug(self.request.POST["signup_method_slug"])
+            signup_method = signup_method_from_slug(
+                self.request.POST["signup_method_slug"], shift=self.object
+            )
             configuration_form = signup_method.get_configuration_form(self.request.POST)
         except ValueError as e:
             raise ValidationError(e) from e
